<?php

namespace Drupal\browser_development\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\browser_development\Processing\FormsStorage;

/**
 * Settings page for editor variables.
 *
 * Drupal\browser_development\Form.
 */
class Settings extends FormBase {

  /**
   * Forms unique identifier.
   *
   * @return string
   *   Returns form unique identifier string
   */
  public function getFormId() {
    return 'browser_development_settings';
  }

  /**
   * Build form array.
   *
   * @param array $form
   *   Adds form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   *
   * @return array
   *   Returns form array elements .
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $uri = "";
    if (!empty(FormsStorage::getStorage('browser_development_settings')['browser_development_settings'])) {
      $uri = FormsStorage::getStorage('browser_development_settings')['browser_development_settings'];
    }
    else {
      $uri = $form_state->getValue('api_uri');
    }

    $form['api_uri'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Api Url'),
      '#default_value' => $uri,
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * Validation method.
   *
   * @param array $form
   *   Array form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * Form submit method.
   *
   * @param array $form
   *   Array form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Gets form state including input values.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $uri = $form_state->getValue('api_uri');
    FormsStorage::setStorage('browser_development_settings', $uri);
    $uriStorage = FormsStorage::getStorage('browser_development_settings')['browser_development_settings'];
    $this->messenger()->addMessage($this->t('You specified a api url of @title.', ['@title' => $uriStorage]));
  }

}
